@@ -79,6 +79,14 @@ class Resolver(BaseModel, T.Generic[NodeType]):
     _fields_to_return: T.Set[str] = PrivateAttr(None)
     _fields_to_include: T.Set[str] = PrivateAttr(default_factory=set)
 
+    _merged: bool = PrivateAttr(False)
+    _metadata: dict = PrivateAttr(default=dict)
+
+    def __hash__(self):
+        return hash(
+            str(self._get_nested_query_variables()) + self.to_str() + self._model_name
+        )
+
     @staticmethod
     def replace_str_with_vars(s: str, d: dict) -> str:
         if not s:
@@ -108,6 +116,8 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         # if other does not have all extra fields that self has, return false
         if self._extra_fields:
             if self.to_compare_extra_str() not in other.to_compare_extra_str():
+                if should_debug:
+                    print("GOING FALSE IN EXTRA FIELDS")
                 return False
 
         # if self has different filters than other, self cannot be a subset
@@ -120,11 +130,17 @@ class Resolver(BaseModel, T.Generic[NodeType]):
             return False
         # now nested resolvers
         if not self._nested_resolvers.is_subset(other._nested_resolvers):
+            if should_debug:
+                print("NESTED RESOLVERS NO GO")
             return False
         return True
 
     """PROPERTIES"""
 
+    @property
+    def metadata(self) -> dict:
+        return self._metadata
+
     @classmethod
     def set_field_dependency_map(cls, field_dep_map: FieldDepMapAlias) -> None:
         cls._field_dependency_map = field_dep_map
